aboutsummaryrefslogtreecommitdiff
path: root/src/definitions
diff options
context:
space:
mode:
authorST-DDT <[email protected]>2022-05-21 16:25:00 +0200
committerGitHub <[email protected]>2022-05-21 14:25:00 +0000
commit5af79f487bd1537676d017ae09563e53d18458c4 (patch)
tree451240689d6a50910e9283bfaa9a56c554cb5eca /src/definitions
parent05f555bc7e304afaa657586ae88f2173507e084f (diff)
downloadfaker-5af79f487bd1537676d017ae09563e53d18458c4.tar.xz
faker-5af79f487bd1537676d017ae09563e53d18458c4.zip
feat: use localized fake pattern in street (#966)
Diffstat (limited to 'src/definitions')
-rw-r--r--src/definitions/address.ts14
1 files changed, 13 insertions, 1 deletions
diff --git a/src/definitions/address.ts b/src/definitions/address.ts
index a7300e5f..49ccb405 100644
--- a/src/definitions/address.ts
+++ b/src/definitions/address.ts
@@ -14,7 +14,11 @@ export type AddressDefinitions = LocaleEntry<{
postcode: string | string[];
/**
- * Names of actual cities
+ * The patterns to generate city names.
+ */
+ city: string[];
+ /**
+ * The names of actual cities.
*/
city_name: string[];
/**
@@ -60,6 +64,14 @@ export type AddressDefinitions = LocaleEntry<{
building_number: string[];
/**
+ * The patterns to generate street names.
+ */
+ street: string[];
+ /**
+ * The names of actual streets.
+ */
+ street_name: string[];
+ /**
* Common street prefixes
*/
street_prefix: string[];